@@ -7,3 +7,7 @@ test_that("list_cluster_snapshots", {
 test_that("list_clusters", {
   expect_error(svc$list_clusters(), NA)
 })
+
+test_that("list_pending_maintenance_actions", {
+  expect_error(svc$list_pending_maintenance_actions(), NA)
+})
